defmodule AdvertisementListContext do
  use WhiteBread.Context
  use Hound.Helpers
  alias PropTrackr.Accounts
  alias PropTrackr.Repo
  alias PropTrackr.Properties.Property

  scenario_starting_state fn _state ->
    Ecto.Adapters.SQL.Sandbox.checkout(PropTrackr.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(PropTrackr.Repo, {:shared, self()})
    Hound.start_session()
    %{}
  end

  scenario_finalize fn _status, _state ->
    Ecto.Adapters.SQL.Sandbox.checkin(PropTrackr.Repo)
    Hound.end_session()
  end

  given_ ~r/^there exists such advertisements$/, fn state, %{table_data: table} ->
    advertisements =
      table                                                                                
      |> Enum.map(fn details -> details |> Map.put(:reference, Ecto.UUID.generate()) end)
      |> Enum.map(fn details -> Property.changeset(%Property{}, details) end)                            
      |> Enum.map(fn changeset -> Repo.insert!(changeset) end)

    {
      :ok,
      state
      |> Map.put(:advertisements, advertisements)
    }
  end

  and_ ~r/^I am not logged in$/, fn state ->
    navigate_to("/logout")
    {:ok, state}
  end

  when_ ~r/^I visit the property advertisement list page$/, fn state ->
    navigate_to("/")
    {:ok, state}
  end

  then_ ~r/^I should see the list of all properties$/, fn state ->
    advertisements = state[:advertisements]
    advertisements |> Enum.each(fn advertisement ->
      assert visible_in_page? ~r/#{advertisement.title}/
      assert visible_in_page? ~r/#{advertisement.description}/
      assert visible_in_page? ~r/#{advertisement.location}/
      assert visible_in_page? ~r/#{advertisement.price}/
      assert visible_in_page? ~r/#{advertisement.room_count}/
      assert visible_in_page? ~r/#{advertisement.area}/
    end)

    {:ok, state}
  end

  then_ ~r/^I should see a message that there is no advertisements$/, fn state ->
    assert visible_in_page? ~r/No advertisements at the moment/
    {:ok, state}
  end
end
