defmodule PropTrackr.Properties.Property do
  use Ecto.Schema
  import Ecto.Changeset

  alias PropTrackr.Repo

  schema "properties" do
    field :title, :string
    field :description, :string

    field :reference, :string

    field :type, Ecto.Enum, values: [:rent, :sell]
    field :property_type, Ecto.Enum, values: [:apartment, :house, :other]
    field :state, Ecto.Enum, values: [:available, :reserved, :unavailable], default: :available

    # TODO: Image references and upload

    field :location, :string

    field :room_count, :integer
    field :area, :float
    field :floor, :integer
    field :floor_count, :integer

    field :price, :float

    belongs_to :user, PropTrackr.Accounts.User

    timestamps()
  end

  def changeset(struct, params \\ %{}) do
    struct
    |> cast(params, [:title, :description, :reference, :type, :property_type, :state, :location, :room_count, :area, :floor, :floor_count, :price, :user_id])
    |> validate_required([:title, :description, :reference, :type, :property_type, :state, :location, :room_count, :area, :floor, :price])
    |> validate_number(:room_count, greater_than: 0)
    |> validate_number(:area, greater_than: 0)
    |> validate_number(:floor, greater_than: 0)
    |> validate_number(:price, greater_than: 0)
    |> validate_length(:title, min: 5)
    |> validate_length(:description, min: 20)
    |> validate_total_floors()
  end

  defp validate_total_floors(changeset) do
    property_type = get_field(changeset, :property_type)

    if property_type != :house do
      floor = get_field(changeset, :floor)
      floor_count = get_field(changeset, :floor_count)

      cond do
        floor_count < floor ->
          changeset
          |> add_error(:floor_count, "Floor count must be greater than floor")
        floor_count < 1 ->
          changeset
          |> add_error(:floor_count, "Floor count must be greater than 0")
        true ->
          changeset
      end
    else
      changeset
    end
  end
end
