defmodule PropTrackrWeb.PropertiesController do
  use PropTrackrWeb, :controller

  import Ecto.Query, only: [from: 2]
  alias PropTrackr.Repo
  alias PropTrackr.Properties.Property

  def index(conn, _params) do
    properties = Repo.all(
                     from p in Property,
                     where: p.state == :available,
                     order_by: [asc: p.inserted_at],
                     select: p)
    render conn, "index.html", properties: properties
  end

  def new(conn, _params) do
    changeset = Property.changeset(%Property{}, %{})
    render conn, "new.html", changeset: changeset
  end

  def create(conn, %{"property" => property}) do
    current_user = conn.assigns.current_user

    if current_user == nil do
      conn
      |> put_flash(:error, "You are not logged in!")
      |> redirect(to: "/")
    else
      property = property |> Map.put("reference", Ecto.UUID.generate())
      property_assoc = Ecto.build_assoc(current_user, :properties, Enum.map(property, fn {key, value} -> {String.to_atom(key), value} end))
      property_changeset = Property.changeset(property_assoc, property)

      # Note: IDK this does not work properly
      # |> Ecto.Changeset.put_change(:reference, Ecto.UUID.generate())

      case Repo.insert(property_changeset) do
        {:ok, property} ->
          conn
          |> put_flash(:info, "Property created successfully!")
          |> redirect(to: ~p"/properties/#{property.reference}")

        {:error, changeset} ->
          render conn, "new.html", changeset: changeset
      end
    end
  end

  def show(conn, %{"id" => id}) do
    # TODO: Fill this in with the appropriate code (FR-12)
    render conn, "index.html", properties: []
  end
end
