defmodule PropTrackrWeb.Router do
  use PropTrackrWeb, :router

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_live_flash
    plug :put_root_layout, html: {PropTrackrWeb.Layouts, :root}
    plug :protect_from_forgery
    plug :put_secure_browser_headers
    plug PropTrackr.Authentication, repo: PropTrackr.Repo
  end

  pipeline :api do
    plug :accepts, ["json"]
  end

  scope "/", PropTrackrWeb do
    pipe_through :browser

    resources "/users", UserController, only: [:index]

    # Authentication
    resources "/register", RegisterController, only: [:index, :create]
    resources "/login", LoginController, only: [:index, :create]
    resources "/logout", LogoutController, only: [:index]

    # User profile
    resources "/me", ProfileController, only: [:index]
    resources "/me/details", UpdateController, only: [:index, :create]
    resources "/me/password", PasswordController, only: [:index, :create]

    # Properties
    get "/", PropertiesController, :index
    get "/properties/new", PropertiesController, :new
    post "/properties", PropertiesController, :create
    get "/properties/:id", PropertiesController, :show
  end

  # Other scopes may use custom stacks.
  # scope "/api", PropTrackrWeb do
  #   pipe_through :api
  # end

  # Enable LiveDashboard and Swoosh mailbox preview in development
  if Application.compile_env(:proptrackr, :dev_routes) do
    # If you want to use the LiveDashboard in production, you should put
    # it behind authentication and allow only admins to access it.
    # If your application does not have an admins-only section yet,
    # you can use Plug.BasicAuth to set up some basic authentication
    # as long as you are also using SSL (which you should anyway).
    import Phoenix.LiveDashboard.Router

    scope "/dev" do
      pipe_through :browser

      live_dashboard "/dashboard", metrics: PropTrackrWeb.Telemetry
      forward "/mailbox", Plug.Swoosh.MailboxPreview
    end
  end
end
